/*
File: AppEventMessage.java
Date		Author		Changes
Sept 6 96	Lukasz Beca	Created
*/

package webwisdom.tango.messages;

import webwisdom.tango.messages.Message;
import webwisdom.tango.consts.Const;
import java.io.*;



/**
 * A class representing message that is send and received by applets and application 
 * 
 *@author Lukasz Beca
 *@see Interfaces in CIV Communication System documentation
 **/

public class AppEventMessage extends Message {
  
  private int len;
  private byte data[];

  /**
   * Creates a new message
   *@param typepar type of message, if type is set to Const.DATA, message will be sent to all applications in the same session; if type is set to Const.CONTROL, message will be sent to local control application 
   *@param datapar table containing information
   *@see Const
   **/

  public AppEventMessage(int typepar, byte datapar[]) {

   int i;

   len = datapar.length;
   data = new byte[len];

   for (i = 0; i < len; i ++) {

     data[i] = datapar[i];

   }
   
   type = typepar;
  }

   /**
   * Creates a new EVENT message, information is read from the input stream
   *@param instream  input stream
   **/

  AppEventMessage(DataInputStream instream) throws IOException {
 
    int n, t = 0;   
 
    type = instream.readInt();
    if ((type == Const.DATA) || (type == Const.CONTROL)) {

      //  System.out.println("AppEventMessage: type of message " + type + " accepted");

      len = instream.readInt();
      data = new byte[len];         
      instream.readFully(data, 0, len);   
	
    }
    else {
      System.out.println("AppEventMessage: type of message " + type + " not supported");
      type = Const.UNDEFINED;
      len = 0;
      data = null;
    }


  }

   /**
   * Writes EVENT message to the output stream
   *@param outstream  output stream
   **/


  void send(DataOutputStream outstream) throws IOException {
  
    int i;


    // System.out.println("Sending type " + type);
    outstream.writeInt(type);
    // System.out.println("Sending length " + len);
    outstream.writeInt(len);
 //  System.out.println("Sending data ");

//      for (i = 0; i < len; i ++) {

//  	System.out.print(data[i]);
//      }

//      System.out.println("");

    outstream.write(data, 0, len);

    outstream.flush();
   
  }
  

  /**
   * Returns length of table containing information
   **/

  public int getLen() {
    
    return len;

  }   

  /**
   * Returns reference to the table with information
   **/

  
  public byte[] getData() {
    
    return data;
  }

}















